# Credits

This ap­plic­a­tion was written by [Ben Welsh](http://palewi.re/who-is-ben-welsh/), [Ken Schwencke](http://schwanksta.com/) and [Armand Emamdjomeh](https://twitter.com/emamd) at the [Los Angeles Times Data Desk](http://datadesk.latimes.com).

The ideas be­hind django-bakery were [first presented at the 2012 con­fer­ence](https://docs.google.com/presentation/d/1IybYcc0eVL-Rchm7lEQNwrM-AHRfr_M8ewfGYYNjeu8/edit) of the [Na­tion­al In­sti­tute for Com­puter-As­sisted Re­port­ing](http://www.ire.org/nicar/). The NICAR com­munity is a con­stant source of chal­lenge and in­spir­a­tion. Many of our ideas, here and else­where, have been ad­ap­ted from things the com­munity has taught us.
